Ext.define('DSS.addon.IlluminantType', {
    extend : 'DSS.component.Base',
    mixins : {
        observable : 'Ext.util.Observable'
    },
    vendorGrid : null,
    typeGrid : null,
    grafic : null,
    macPanel : null,
    iDefaultWidth : 150,
    iDefaultHeight : 293,
    iSelectedID:null,
    setHeight : function(oHeight) {
        this.macPanel.setHeight(oHeight - 100);
        this.iDefaultHeight = oHeight - 102;
        if (this.vendorGrid != null)
            this.vendorGrid.setHeight(this.iDefaultHeight);
        if (this.typeGrid != null)
            this.typeGrid.setHeight(this.iDefaultHeight);
        this.callParent(arguments);
    },
    initStores : function() {
        if (Ext.data.StoreManager.lookup('illuminateChartValues') == null) {
            Ext.create('Ext.data.Store', {
                storeId : 'illuminateChartValues',
                fields : [ 'id','value'],
                proxy : {
                    type : 'memory',
                    reader : {
                        type : 'json',
                        root : 'items'
                    }
                }
            });   
        }
    },
    constructGrid : function() {
        var lvlTypeStore = Ext.create('Ext.data.Store', {
            fields : [ 'id', 'type', 'socket','capatility' ],
            proxy : {
                type : 'memory',
                reader : {
                    type : 'json',
                    root : 'items'
                }
            }
        });
        
        this.vendorGrid = Ext.create('Ext.grid.Panel', {
            height : this.iDefaultHeight,
            width : 150,
            autoScroll : true,
            viewConfig : {
                stripeRows : true
            },
            store : Ext.data.StoreManager.lookup('illuminateVendorStore'),
            columns : [ {
                sortable : false,
                hideable : false,
                text : _('Vendor'),
                dataIndex : 'vendor',
                flex : 1
            } ]
        });
        this.vendorGrid.parent = this;

        this.typeGrid = Ext.create('Ext.grid.Panel', {
            height : this.iDefaultHeight,
            width : 624,
            autoScroll : true,
            viewConfig : {
                stripeRows : true
            },
            store:Ext.data.StoreManager.lookup('illuminateTypeStore'),
            columns : [ {
                sortable : false,
                hideable : false,
                text : _('Socket'),
                dataIndex : 'socket',
                width: 40
            },
            {
                sortable : false,
                hideable : false,
                text : _('Type'),
                dataIndex : 'type',
                flex : 4
            },
            {
                sortable : false,
                hideable : false,
                text : _('dimming capatility'),
                dataIndex : 'Eignung',
                renderer: function (value)
                {
                    switch(value) {
                        case 1: 
                            return '<img src="images/status_ok.png"/>';
                            break;
                        case 0:
                        case -1: 
                            return '<img src="images/status_critical.png"/>';
                            break;
                        case 9:
                            return '<img src="images/status_error.png"/>';
                            break;
                        default: 
                            return '<img src="images/status_critical.png"/>';
                            break;
                    }
                },
                width: 100
            } ]
        });
        this.typeGrid.parent = this;

        
        this.vendorGrid.on('itemclick', function(grid, record) {
            Ext.data.StoreManager.lookup('illuminateTypeStore').clearFilter();
            Ext.data.StoreManager.lookup('illuminateTypeStore').filter('vendorId',record.get('id'));
            this.parent.macPanel.doLayout();
        });
        

        this.typeGrid.on('selectionchange', function(model,record) {
            Ext.data.StoreManager.lookup('illuminateChartValues').removeAll();
            if (record.length>0) {
                var oValue=record[0].get('Evals');
                this.parent.iSelectedID=record[0].get('id');
                for (var iIndex=0;iIndex<oValue.length;iIndex++) {
                    Ext.data.StoreManager.lookup('illuminateChartValues').add({id:iIndex,value:oValue[iIndex]});
                }
                if (this.parent.dssEditor.editControls.aaa!=null)
                    this.parent.dssEditor.editControls.aaa.setIllumantLabel(record[0].get('type'));
                this.parent.macPanel.doLayout();
            }
        });

    },
    constructor : function(config) {

        
        this.initStores();
        this.constructGrid();
        this.macPanel = Ext.create('Ext.panel.Panel', {
            border : '0',
            autoScroll : true,
            height : 220,
            width : 774,
            layout : {
                type : 'hbox',
                flex:0
            },
            items : [ this.vendorGrid,this.typeGrid  ],
            scroll : 'horizontal'
        });

        this.grafic = Ext.create('Ext.chart.Chart', {
            store:Ext.data.StoreManager.lookup('illuminateChartValues'),
            height : 100,
            width: 400,
            animate: true,
            series: [ {
                         type: 'line',
                         xField: 'id',
                         yField: 'value',
                         fill: true,
                         markerConfig: {
                             type: 'circle',
                             radius: 4,
                             'fill': '#ffff00'
                         }
                     }]
        });

        Ext.apply(this, {
            layout : {
                type : 'vbox'
            },
           
            items : [ this.macPanel, this.grafic ]
        });
        this.callParent(arguments);
    },
    reset : function() {
        this.setValue(0);
    },
    setValue : function(value) {
        this.iSelectedID=value;
        
        Ext.data.StoreManager.lookup('illuminateChartValues').removeAll();
        
        var record=Ext.data.StoreManager.lookup('illuminateTypeStore').findRecord('id',value,0,false,false,true);
        
        
        var oValue=record.get('Evals');
        iSelectedID=record.get('id');
        for (var iIndex=0;iIndex<oValue.length;iIndex++) {
            Ext.data.StoreManager.lookup('illuminateChartValues').add({id:iIndex,value:oValue[iIndex]});
        }
        this.macPanel.doLayout();
        if (this.dssEditor.editControls.aaa!=null)
            this.dssEditor.editControls.aaa.setIllumantLabel(record.get('type'));
    },
    isValid : function() {
        return true;
    },
    getValue : function() {
        return this.iSelectedID;
    }
});
